@@ -3,7 +3,7 @@ from django.views.decorators.csrf import csrf_protect
 from django.template import loader, Template, RequestContext
 import urllib
 from facebook_comments.models import FacebookCommentCache
-from facebook.conf import settings
+from facebook_comments.conf import settings
 
 def recache(request):
 	if request.method == 'POST':
